summary refs log tree commit diff
path: root/synapse/rest/client/relations.py
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2021-11-23 06:43:56 -0500
committerGitHub <noreply@github.com>2021-11-23 06:43:56 -0500
commit6a5dd485bd82b269e7e169c0385290d081eae801 (patch)
tree34296b57c6efd2daf3e5f5605bcbdd8fc31a2273 /synapse/rest/client/relations.py
parentAdd config for customizing the claim used for JWT logins. (#11361) (diff)
downloadsynapse-6a5dd485bd82b269e7e169c0385290d081eae801.tar.xz
Refactor the code to inject bundled relations during serialization. (#11408)
Diffstat (limited to 'synapse/rest/client/relations.py')
-rw-r--r--synapse/rest/client/relations.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/synapse/rest/client/relations.py b/synapse/rest/client/relations.py
index 184cfbe196..45e9f1dd90 100644
--- a/synapse/rest/client/relations.py
+++ b/synapse/rest/client/relations.py
@@ -224,17 +224,17 @@ class RelationPaginationServlet(RestServlet):
         )
 
         now = self.clock.time_msec()
         # We set bundle_aggregations to False when retrieving the original
         # event because we want the content before relations were applied to
         # it.
         original_event = await self._event_serializer.serialize_event(
-            event, now, bundle_aggregations=False
+            event, now, bundle_relations=False
         )
         # Similarly, we don't allow relations to be applied to relations, so we
         # return the original relations without any aggregations on top of them
         # here.
         serialized_events = await self._event_serializer.serialize_events(
-            events, now, bundle_aggregations=False
+            events, now, bundle_relations=False
         )
 
         return_value = pagination_chunk.to_dict()
@@ -224,17 +224,17 @@ class RelationPaginationServlet(RestServlet):
 
         now = self.clock.time_msec()
-        # We set bundle_aggregations to False when retrieving the original
+        # We set bundle_relations to False when retrieving the original
         # event because we want the content before relations were applied to
         # it.